//% color="#17959d" iconWidth=50 iconHeight=40
namespace BadgeDisplay {
    //% block="BadgeDisplay initialize software serial RX:[RX] TX:[TX]" blockType="command"
    //% RX.shadow="dropdown" RX.options="RX"
    //% TX.shadow="dropdown" TX.options="TX"
    export function BadgeDisplay_Init(parameter: any, block: any) {
        let rx = parameter.RX.code;
        let tx = parameter.TX.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        Generator.addObject("addHuiZhang","HuiZhang",`hz(${rx}, ${tx});`)
    }

    //% block="BadgeDisplay Clear Screen" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    export function BadgeDisplay_Clear_Screen(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        Generator.addCode(`hz.SendClr();`)
    }

    //% block="BadgeDisplay display Number[NUM]" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    //% NUM.shadow="number" NUM.defl=123
    export function displayNum(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        let num = parameter.NUM.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // Generator.addObject(`displayNum`, `void`, `displayNum_${pin}(String num) {\n\thz.Send('n');\n\t${pin}.Send(num);\n}`);
        // if (Generator.board !== 'esp32') {
        //     Generator.addSetup(`${pin}.begin`, `${pin}.begin(115200);`);
        // }
        // Generator.addCode(`displayNum_${pin}(String(${num}));`)
        Generator.addCode(`hz.SendNum(String(${num}));`)
    }

    //% block="BadgeDisplay display Number[NUM] at X[X]" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    //% X.shadow="range" X.params.min="1" X.params.max="44" X.defl="1"
    //% NUM.shadow="number" NUM.defl=123
    export function displayNumAtX(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        let x = parameter.X.code;
        let num = parameter.NUM.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // Generator.addObject(`displayNumAtX`, `void`, `displayNumAtX_${pin}(String num, int x) {\n\thz.Send('n');\n\thz.Send(x);\n\thz.Send('/');\n\t${pin}.Send(num);\n}`);
        // if (Generator.board !== 'esp32') {
        //     Generator.addSetup(`${pin}.begin`, `${pin}.begin(115200);`);
        // }
        Generator.addCode(`hz.SendNumAtX(String(${num}),${x});`)
    }

    //% block="BadgeDisplay display String[STR]" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    //% STR.shadow="string" STR.defl="YES"
    export function displayStr(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        let str = parameter.STR.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // Generator.addObject(`displayStr`, `void`, `displayStr_${pin}(String str) {\n\thz.Send('s');\n\t${pin}.Send(str);\n}`);
        // if (Generator.board !== 'esp32') {
        //     Generator.addSetup(`${pin}.begin`, `${pin}.begin(115200);`);
        // }
        // Generator.addCode(`displayStr_${pin}(String(${str}));`)
        Generator.addCode(`hz.SendStr(String(${str}));`)
    }

    //% block="BadgeDisplay display String[STR] at X[X]" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    //% X.shadow="range" X.params.min="1" X.params.max="44" X.defl="1"
    //% STR.shadow="string" STR.defl="YES"
    export function displayStrAtX(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        let x = parameter.X.code;
        let str = parameter.STR.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // Generator.addObject(`displayStrAtX`, `void`, `displayStrAtX_${pin}(String str, int x) {\n\thz.Send('s');\n\thz.Send(x);\n\thz.Send('/');\n\t${pin}.Send(str);\n}`);
        // if (Generator.board !== 'esp32') {
        //     Generator.addSetup(`${pin}.begin`, `${pin}.begin(115200);`);
        // }
        // Generator.addCode(`displayStrAtX_${pin}(String(${str}), ${x});`)
        Generator.addCode(`hz.SendStrAtX(String(${str}),${x});`)
    }

    //% block="BadgeDisplay Matrix Start at Screen[X] Row[Y]" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    //% X.shadow="range" X.params.min="1" X.params.max="4" X.defl="1"
    //% Y.shadow="range" Y.params.min="1" Y.params.max="11" Y.defl="1"
    export function displayMatrixAxis(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        let x = parameter.X.code;
        let y = parameter.Y.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // if (Generator.board !== 'esp32') {
        //     Generator.addSetup(`${pin}.begin`, `${pin}.begin(115200);`);
        // }
        // Generator.addObject(`displayMatrixAxis`, `void`, `displayMatrixAxis_${pin}(int x, int y) {\n\thz.Send('m');\n\thz.Send('x');\n\thz.Send(x);\n\thz.Send('y');\n\thz.Send(y);\n\thz.Send('/');\n}`);
        // Generator.addCode(`displayMatrixAxis_${pin}(${x}, ${y});`)
        Generator.addCode(`hz.SendMatrixAxis(${x}, ${y});`)
    }

    //% block="BadgeDisplay Matrix[SDR1][SDR2][SDR3][SDR4][SDR5][SDR6][SDR7][SDR8][SDR9][SDR10][SDR11]" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    //% SDR1.shadow="range" SDR1.params.min="0" SDR1.params.max="1" SDR1.defl="0"
    //% SDR2.shadow="range" SDR2.params.min="0" SDR2.params.max="1" SDR2.defl="0"
    //% SDR3.shadow="range" SDR3.params.min="0" SDR3.params.max="1" SDR3.defl="0"
    //% SDR4.shadow="range" SDR4.params.min="0" SDR4.params.max="1" SDR4.defl="0"
    //% SDR5.shadow="range" SDR5.params.min="0" SDR5.params.max="1" SDR5.defl="0"
    //% SDR6.shadow="range" SDR6.params.min="0" SDR6.params.max="1" SDR6.defl="0"
    //% SDR7.shadow="range" SDR7.params.min="0" SDR7.params.max="1" SDR7.defl="0"
    //% SDR8.shadow="range" SDR8.params.min="0" SDR8.params.max="1" SDR8.defl="0"
    //% SDR9.shadow="range" SDR9.params.min="0" SDR9.params.max="1" SDR9.defl="0"
    //% SDR10.shadow="range" SDR10.params.min="0" SDR10.params.max="1" SDR10.defl="0"
    //% SDR11.shadow="range" SDR11.params.min="0" SDR11.params.max="1" SDR11.defl="0"
    //% SERIAL1.shadow="dropdownRound" SERIAL1.options="SDR"
    export function displayMatrix(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        let sdr:any[] = [parameter.SDR1.code, parameter.SDR2.code, parameter.SDR3.code, parameter.SDR4.code, parameter.SDR5.code, parameter.SDR6.code, parameter.SDR7.code, parameter.SDR8.code, parameter.SDR9.code, parameter.SDR10.code, parameter.SDR11.code];
        // sdr[0] = parameter.SDR1.code;
        // sdr[1] = parameter.SDR2.code;
        // sdr[2] = parameter.SDR3.code;
        // sdr[3] = parameter.SDR4.code;
        // sdr[4] = parameter.SDR5.code;
        // sdr[5] = parameter.SDR6.code;
        // sdr[6] = parameter.SDR7.code;
        // sdr[7] = parameter.SDR8.code;
        // sdr[8] = parameter.SDR9.code;
        // sdr[9] = parameter.SDR10.code;
        // sdr[10] = parameter.SDR11.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // Generator.addObject(`displayMatrix`, `void`, `displayMatrix_${pin}(bool num1, bool num2, bool num3, bool num4, bool num5, bool num6, bool num7, bool num8, bool num9, bool num10, bool num11) {\n\thz.Send(num1);\n\thz.Send(num2);\n\thz.Send(num3);\n\thz.Send(num4);\n\thz.Send(num5);\n\thz.Send(num6);\n\thz.Send(num7);\n\thz.Send(num8);\n\thz.Send(num9);\n\thz.Send(num10);\n\thz.Send(num11);\n}`);
        // Generator.addCode(`displayMatrix_${pin}(${sdr1}, ${sdr2}, ${sdr3}, ${sdr4}, ${sdr5}, ${sdr6}, ${sdr7}, ${sdr8}, ${sdr9}, ${sdr10}, ${sdr11});`)
        let value:any = 0;
        // let value1:string = '';
        for (let index = 0; index < sdr.length; index++) {
            // if (sdr[index] == 0 || sdr[index] == 1) {
            value += sdr[index] << (10 - index);
            // } else {
            //     value1 += ' + ' + sdr[index] + ' << ' + (10 - index);
            // }
        }
        if (value < 0x10) {
            value = "0x00" + value.toString(16);
        } else if (value < 0x100) {
            value = "0x0" + value.toString(16);
        } else {
            value = "0x" + value.toString(16);
        }
        Generator.addCode(`hz.SendMatrix("${value}");`)
    }

    //% block="BadgeDisplay Matrix End" blockType="command"
    //% PIN.shadow="dropdown" PIN.options="PIN"
    export function displayMatrixEnd(parameter: any, block: any) {
        // let pin = parameter.PIN.code;
        Generator.addInclude("addIncludeHuizhang","#include <Huizhang.h>");
        // Generator.addObject("addHuiZhang","HuiZhang",`hz_${pin}(${pin});`);
        // Generator.addCode(`${pin}.Send();`)
        Generator.addCode(`hz.SendMatrixDisplay();`)
    }
}